@@ -4,7 +4,7 @@
 # This program is free software; you can redistribute it and/or 
 # modify it under the same terms as Perl itself. 
 #
-# Ident = $Id: Jvm.pm,v 1.20 2001/09/08 07:03:37 yw Exp $
+# Ident = $Id: Jvm.pm,v 1.16 2000/09/24 04:42:46 yw Exp $
 
 #############################
 package jobject;
@@ -114,15 +114,13 @@ package Jvm;
 ##############################
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $DEBUG $CLASSPATH $LIBPATH);
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $DEBUG);
 
 require Exporter;
 require DynaLoader;
 require AutoLoader;
 
 $DEBUG = 0;
-$CLASSPATH = "."; #just to get rid of "-w" warnings.
-$LIBPATH   = ".";
 
 @ISA = qw(Exporter DynaLoader);
 # Items to export into callers namespace by default. Note: do not export
@@ -131,7 +129,7 @@ $LIBPATH   = ".";
 @EXPORT = qw(
 	
 );
-$VERSION = '0.9.2';
+$VERSION = '0.9';
 
 bootstrap Jvm $VERSION;
 
@@ -531,29 +529,9 @@ set B<static> member of class $class to $value.
 
 This function invokes "System.out.println($obj)" to dump the java object $obj.
 
-=head1 Global variables
-
-The global variables below are optional.
-
-=item CLASSPATH
-
-The path(s) where the Java VM searches for java class files
-
-$Jvm::CLASSPATH = "/home/java/classes";
-
-=item LIBPATH
-
-The path(s) where the Java VM searches for JNI libraries
-
-$Jvm::LIBPATH = "/home/java/classes/native";
-
 =head1 AUTHOR
 
-Ye, Wei      w_e_i_y_e@yahoo.com
-
-=head1 CREDITS
-
-Claes Jacobsson (claes@contiller.se) - $Jvm::CLASSPATH and $Jvm::LIBPATH
+Ye, Wei      yw@alabanza.net
 
 =head1 SEE ALSO
 
